@@ -24,10 +24,10 @@ def create_app(config):
     if app.config.get('SQLALCHEMY_DATABASE_URI'):
         init_sqlalchemy(app)
 
-    if app.config.get('MONGO_URI'):
+    if app.config.get('MONGODB_SETTINGS'):
         init_mongodb(app)
 
-    if app.config.get('CELERY_BROKER_URL') and app.config.get('RESULT_BACKEND'):
+    if app.config.get('CELERY'):
         init_celery(app)
 
     if app.config.get('PROCESSOR'):
@@ -36,7 +36,9 @@ def create_app(config):
         processor = Processor()
         processor.start()
         app.processor = processor
-
+    else:
+        app.processor = None
+        
     if config.MODULES:
         app.modules = load_modules(config.MODULES)
     
@@ -92,9 +94,9 @@ def init_sqlalchemy(app):
 
 def init_mongodb(app):
     app.logger.info('初始化MongoDB...')
-    from flask_pymongo import PyMongo
+    from flask_mongoengine import MongoEngine
     from webcore.mongo_encoder import MongoEncoder
-    mongo_db = PyMongo(app)
+    mongo_db = MongoEngine(app)
     app.mongo_db = mongo_db
     app.register_encoder(MongoEncoder())
 
@@ -104,11 +106,11 @@ def init_celery(app):
 
     celery = Celery(
         app.import_name,
-        backend = app.config['RESULT_BACKEND'],
-        broker = app.config['CELERY_BROKER_URL']
+        backend = app.config['CELERY']['result_backend'],
+        broker = app.config['CELERY']['celery_broker_url']
     )
 
-    celery.conf.update(app.config)
+    celery.conf.update(app.config['CELERY'])
 
     class ContextTask(celery.Task):
         def __call__(self, *args, **kwargs):
