@@ -8,7 +8,7 @@ from . import exception
 
 def _handle_error(e):
     if isinstance(e, HTTPException):
-        app.logger.error('Http Exception.', exc_info = True)
+        app.logger.error('Http Exception, code: {}, message: {}'.format(e.code, e.description))
         
         if e.code == 400:
             return Result.http_error(e.data.get('message'))
