@@ -9,9 +9,14 @@ from .interceptor import init_interceptor
 
 class GtFlask(Flask):
     def make_response(self, rv):
-        if isinstance(rv, Result):
-            return super().make_response(jsonify(rv))
-        return super().make_response(rv)
+        try:
+            if isinstance(rv, Result):
+                return super().make_response(jsonify(rv))
+            else:
+                return super().make_response(rv)
+        except Exception as e:
+            self.logger.error(e)
+            return super().make_response(jsonify(Result.error()))
 
     def init_app(self):
         CORS(self, resources={r'/*': {"origins": '*'}})
